Optimisation
============

A package of the optimisation classes used in `CGExplore`.

Energy calculators
------------------

.. toctree::
  :maxdepth: 1

  CGOMMSinglePoint <_autosummary/cgexplore.optimisation.CGOMMSinglePoint>

Geometry optimisations
----------------------

.. toctree::
  :maxdepth: 1

  CGOMMOptimizer <_autosummary/cgexplore.optimisation.CGOMMOptimizer>


Dynamics
--------

.. toctree::
  :maxdepth: 1

  CGOMMDynamics <_autosummary/cgexplore.optimisation.CGOMMDynamics>
  OMMTrajectory <_autosummary/cgexplore.optimisation.OMMTrajectory>


